API docs for “spamfighter.core.commands.test.test_partner”

# Module s.c.c.t.test_partner

Part of spamfighter.core.commands.test View Source

Тесты на `spamfighter.core.commands.partner`.

Class | FakePartneredCommand | Undocumented
Class | FakeDomainedCommand | Undocumented
Class | PartneredCommandTestCase | Тест на `spamfighter.core.commands.partner.PartneredCommand`.
Class | DomainedCommandTestCase | Тест на `spamfighter.core.commands.partner.DomainedCommand`.